[−][src]Module intercom_common::generators
Generators for file formats that can be derived from the intercom libraries.
Requires the optional generators feature
Modules
| cpp | Enables the generation of header and source files for using intercom libraries from C++ projects. |
| idl | Enables the generation of IDL file that describes intercom library. |
| manifest | Enables the generation of manifest file for registration free COM on Windows. |
Enums
| GeneratorError | A common error type for all the generators. |