[−][src]Module intercom_common::prelude
Structs
| Ident | A word of Rust code, which may be a keyword or legal variable name. |
| Span | A region of source code, along with macro expansion information. |
| TokenStream | An abstract stream of tokens, or more concretely a sequence of token trees. |
| TokenStreamNightly | The main type provided by this crate, representing an abstract stream of tokens, or, more specifically, a sequence of token trees. The type provide interfaces for iterating over those token trees and, conversely, collecting a number of token trees into one stream. |