[][src]Struct intercom_common::tyhandlers::TypeConversion

pub struct TypeConversion {
    pub temporary: Option<TokenStream>,
    pub value: TokenStream,
}

Fields

temporary: Option<TokenStream>

Possible temporary values that need to be kept alive for the duration of the conversion result usage.

value: TokenStream

Conversion result value. Possibly referencing the temporary value.