Trait intercom_common::returnhandlers::ReturnHandler [] [src]

pub trait ReturnHandler {
    fn rust_ty(&self) -> Ty;

    fn com_ty(&self) -> Ty { ... }
fn com_to_rust_return(&self, _result: &Ident) -> Tokens { ... }
fn rust_to_com_return(&self, _result: &Ident) -> Tokens { ... }
fn com_out_args(&self) -> Vec<ComArg> { ... } }

Defines return handler for handling various different return type schemes.

Required Methods

The return type of the original Rust method.

Provided Methods

The return type for COM implementation.

Gets the return statement for converting the COM result into Rust return.

Gets the return statement for converting the Rust result into COM outputs.

Gets the COM out arguments that result from the Rust return type.

Implementors