[−][src]Struct intercom_common::tyhandlers::TypeConversion
Fields
temporary: Option<TokenStream>Possible temporary values that need to be kept alive for the duration of the conversion result usage.
value: TokenStreamConversion result value. Possibly referencing the temporary value.