Trait intercom_common::tyhandlers::TyHandler
[−]
[src]
pub trait TyHandler {
fn rust_ty(&self) -> Ty;
fn com_ty(&self) -> Ty { ... }
fn com_to_rust(&self, ident: &Ident) -> Tokens { ... }
fn rust_to_com(&self, ident: &Ident) -> Tokens { ... }
fn default_value(&self) -> Tokens { ... }
}Defines Type-specific logic for handling the various parameter types in the Rust/COM interface.
Required Methods
Provided Methods
fn com_ty(&self) -> Ty
The COM type.
fn com_to_rust(&self, ident: &Ident) -> Tokens
Converts a COM parameter named by the ident into a Rust type.
fn rust_to_com(&self, ident: &Ident) -> Tokens
Converts a Rust parameter named by the ident into a COM type.
fn default_value(&self) -> Tokens
Gets the default value for the type.